@@ -26,7 +26,9 @@
 
 #include <QDialog>
 
-class QString;
+class QDialogButtonBox;
+class QLabel;
+class QLineEdit;
 namespace KPIMTextEdit {
 /**
     @short Dialog to allow user to configure a hyperlink.
@@ -79,14 +81,13 @@ public:
      */
     QString linkUrl() const;
 
-private Q_SLOTS:
-    void slotTextChanged(const QString &);
-
 private:
-    //@cond PRIVATE
-    class KLinkDialogPrivate;
-    KLinkDialogPrivate *const d;
-    //@endcond
+    void slotTextChanged(const QString &);
+    QLabel *textLabel = nullptr;
+    QLineEdit *textLineEdit = nullptr;
+    QLabel *linkUrlLabel = nullptr;
+    QLineEdit *linkUrlLineEdit = nullptr;
+    QDialogButtonBox *buttonBox = nullptr;
 };
 }
 //@endcond
