@@ -89,7 +89,7 @@ KPIMTextEdit::RichTextComposerActions *RichTextComposer::composerActions() const
     return d->richTextComposerActions;
 }
 
-QList<QAction *> RichTextComposer::richTextActionList() const
+QVector<QAction *> RichTextComposer::richTextActionList() const
 {
     return d->richTextComposerActions->richTextActionList();
 }
@@ -514,6 +514,28 @@ void RichTextComposer::insertFromMimeData(const QMimeData *source)
         }
     }
 
+    if (textMode() == RichTextComposer::Rich) {
+        if (source->hasText()) {
+            const QString sourceText = source->text();
+            if (sourceText.startsWith(QStringLiteral("http://"))
+                || sourceText.startsWith(QStringLiteral("https://"))
+                || sourceText.startsWith(QStringLiteral("ftps://"))
+                || sourceText.startsWith(QStringLiteral("ftp://"))
+                || sourceText.startsWith(QStringLiteral("mailto:"))
+                || sourceText.startsWith(QStringLiteral("smb://"))
+                || sourceText.startsWith(QStringLiteral("file://"))
+                || sourceText.startsWith(QStringLiteral("webdavs://"))
+                || sourceText.startsWith(QStringLiteral("imaps://"))
+                || sourceText.startsWith(QStringLiteral("sftp://"))
+                || sourceText.startsWith(QStringLiteral("fish://"))
+                || sourceText.startsWith(QStringLiteral("tel:"))
+                ) {
+                insertHtml(QStringLiteral("<a href=\"%1\">%1</a> ").arg(sourceText));
+                return;
+            }
+        }
+    }
+
     KPIMTextEdit::RichTextEditor::insertFromMimeData(source);
 }
 
