@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2012-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,6 +24,7 @@
 #include <klineedit.h>
 #include <KColorScheme>
 
+#include <QRegularExpression>
 #include <QPlainTextEdit>
 
 using namespace KPIMTextEdit;
@@ -73,6 +74,7 @@ bool PlainTextEditFindBar::searchInDocument(const QString &text, QTextDocument::
     return found;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
 bool PlainTextEditFindBar::searchInDocument(const QRegExp &regExp, QTextDocument::FindFlags searchOptions)
 {
     const bool found = d->mView->find(regExp, searchOptions);
@@ -80,6 +82,16 @@ bool PlainTextEditFindBar::searchInDocument(const QRegExp &regExp, QTextDocument
     return found;
 }
 
+#else
+bool PlainTextEditFindBar::searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions)
+{
+    const bool found = d->mView->find(regExp, searchOptions);
+    mFindWidget->setFoundMatch(found);
+    return found;
+}
+
+#endif
+
 void PlainTextEditFindBar::autoSearchMoveCursor()
 {
     QTextCursor cursor = d->mView->textCursor();
